==> trade-center-biz-0.2.2-ZDX-20161103.125609-1-sources.jar: cn/com/duiba/order/center/biz/dao/activity/ActivityOrderDao.java <==
package cn.com.duiba.order.center.biz.dao.activity;

import java.util.List;

import org.apache.ibatis.annotations.Param;

import cn.com.duiba.order.center.biz.entity.ActivityOrderEntity;

/**
 * 
 * @author zhaodongxue
 *
 */
public interface ActivityOrderDao {

	public void insert(ActivityOrderEntity entity);

	public ActivityOrderEntity find(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum);
	
	public int updateCreditsSuccess(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("activityOptionId")Long activityOptionId, 
			@Param("activityOptionName")String activityOptionName, 
			@Param("activityOptionType")String activityOptionType, 
			@Param("facePrice")String facePrice, 
			@Param("appItemId")Long appItemId, 
			@Param("itemId")Long itemId, 
			@Param("gid")Long gid, 
			@Param("gtype")String gtype, 
			@Param("couponId")Long couponId,
			@Param("consumeCreditsStatus")int consumeCreditsStatus);
	
	public int updateCreditsSuccessDowngrade(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("activityOptionId")Long activityOptionId, 
			@Param("activityOptionName")String activityOptionName, 
			@Param("activityOptionType")String activityOptionType, 
			@Param("facePrice")String facePrice, 
			@Param("appItemId")Long appItemId, 
			@Param("itemId")Long itemId, 
			@Param("gid")Long gid, 
			@Param("gtype")String gtype, 
			@Param("couponId")Long couponId,
			@Param("consumeCreditsStatus")int consumeCreditsStatus);
	
	public int updateCreditsFail(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("activityOptionId")Long activityOptionId, 
			@Param("activityOptionName")String activityOptionName, 
			@Param("activityOptionType")String activityOptionType, 
			@Param("facePrice")String facePrice, 
			@Param("appItemId")Long appItemId, 
			@Param("itemId")Long itemId, 
			@Param("gid")Long gid, 
			@Param("gtype")String gtype, 
			@Param("couponId")Long couponId, 
			@Param("error4admin")String error4admin, 
			@Param("error4developer")String error4developer, 
			@Param("error4consumer")String error4consumer,
			@Param("consumeCreditsStatus")int consumeCreditsStatus);
	
	public int updateAddCreditsSuccess(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("activityOptionId")Long activityOptionId, 
			@Param("activityOptionName")String activityOptionName, 
			@Param("activityOptionType")String activityOptionType, 
			@Param("facePrice")String facePrice, 
			@Param("appItemId")Long appItemId, 
			@Param("itemId")Long itemId, 
			@Param("gid")Long gid, 
			@Param("gtype")String gtype, 
			@Param("couponId")Long couponId,
			@Param("addCreditsStatus")int addCreditsStatus);
	
	public int updateAddCreditsFail(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("activityOptionId")Long activityOptionId, 
			@Param("activityOptionName")String activityOptionName, 
			@Param("activityOptionType")String activityOptionType, 
			@Param("facePrice")String facePrice, 
			@Param("appItemId")Long appItemId, 
			@Param("itemId")Long itemId, 
			@Param("gid")Long gid, 
			@Param("gtype")String gtype, 
			@Param("couponId")Long couponId, 
			@Param("error4admin")String error4admin, 
			@Param("error4developer")String error4developer, 
			@Param("error4consumer")String error4consumer,
			@Param("addCreditsStatus")int addCreditsStatus);
	
	public int updateExchangeStatus(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("exchangeStatus")int exchangeStatus);
	
	public int updateDeveloperBizId(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("bizId")String bizId);
	
	public int updateAddDeveloperBizId(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("bizId")String bizId);
	
	public int updateMainOrderNum(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("mainOrderNum")String mainOrderNum);
	
	public int countConsumerJoinNum(@Param("suffix")String suffix,
			@Param("consumerId")long consumerId, 
			@Param("duibaActivityId")long duibaActivityId, 
			@Param("activityType")String activityType);
	
	public List<ActivityOrderEntity> findConsumerJoinList(@Param("suffix")String suffix,
			@Param("consumerId")long consumerId, 
			@Param("duibaActivityIds")List<Long> duibaActivityIds, 
			@Param("activityType")String activityType);
	
	public List<ActivityOrderEntity> findByOrderNums(@Param("suffix")String suffix,
			@Param("orderNums") List<String> orderNums);
	
	public List<Long> findOptionIds(@Param("consumerId")Long consumerId, 
			@Param("appId")Long appId, 
			@Param("activityType")String activityType,
			@Param("suffix")String suffix);
	
}

==> trade-center-biz-0.2.7-ZDX-20161114.122234-1-sources.jar: cn/com/duiba/order/center/biz/dao/activity/ActivityOrderDao.java <==
package cn.com.duiba.order.center.biz.dao.activity;

import java.util.List;

import org.apache.ibatis.annotations.Param;

import cn.com.duiba.order.center.biz.entity.ActivityOrderEntity;

/**
 * 
 * @author zhaodongxue
 *
 */
public interface ActivityOrderDao {

	public void insert(ActivityOrderEntity entity);

	public ActivityOrderEntity find(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum);
	
	public int updateCreditsSuccess(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("activityOptionId")Long activityOptionId, 
			@Param("activityOptionName")String activityOptionName, 
			@Param("activityOptionType")String activityOptionType, 
			@Param("facePrice")String facePrice, 
			@Param("appItemId")Long appItemId, 
			@Param("itemId")Long itemId, 
			@Param("gid")Long gid, 
			@Param("gtype")String gtype, 
			@Param("couponId")Long couponId,
			@Param("consumeCreditsStatus")int consumeCreditsStatus);
	
	public int updateCreditsSuccessDowngrade(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("activityOptionId")Long activityOptionId, 
			@Param("activityOptionName")String activityOptionName, 
			@Param("activityOptionType")String activityOptionType, 
			@Param("facePrice")String facePrice, 
			@Param("appItemId")Long appItemId, 
			@Param("itemId")Long itemId, 
			@Param("gid")Long gid, 
			@Param("gtype")String gtype, 
			@Param("couponId")Long couponId,
			@Param("consumeCreditsStatus")int consumeCreditsStatus);
	
	public int updateCreditsFail(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("activityOptionId")Long activityOptionId, 
			@Param("activityOptionName")String activityOptionName, 
			@Param("activityOptionType")String activityOptionType, 
			@Param("facePrice")String facePrice, 
			@Param("appItemId")Long appItemId, 
			@Param("itemId")Long itemId, 
			@Param("gid")Long gid, 
			@Param("gtype")String gtype, 
			@Param("couponId")Long couponId, 
			@Param("error4admin")String error4admin, 
			@Param("error4developer")String error4developer, 
			@Param("error4consumer")String error4consumer,
			@Param("consumeCreditsStatus")int consumeCreditsStatus);
	
	public int updateAddCreditsSuccess(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("activityOptionId")Long activityOptionId, 
			@Param("activityOptionName")String activityOptionName, 
			@Param("activityOptionType")String activityOptionType, 
			@Param("facePrice")String facePrice, 
			@Param("appItemId")Long appItemId, 
			@Param("itemId")Long itemId, 
			@Param("gid")Long gid, 
			@Param("gtype")String gtype, 
			@Param("couponId")Long couponId,
			@Param("addCreditsStatus")int addCreditsStatus);
	
	public int updateAddCreditsFail(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("activityOptionId")Long activityOptionId, 
			@Param("activityOptionName")String activityOptionName, 
			@Param("activityOptionType")String activityOptionType, 
			@Param("facePrice")String facePrice, 
			@Param("appItemId")Long appItemId, 
			@Param("itemId")Long itemId, 
			@Param("gid")Long gid, 
			@Param("gtype")String gtype, 
			@Param("couponId")Long couponId, 
			@Param("error4admin")String error4admin, 
			@Param("error4developer")String error4developer, 
			@Param("error4consumer")String error4consumer,
			@Param("addCreditsStatus")int addCreditsStatus);
	
	int addCreditsStatusToProcessing(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("status")int status);
	
	public int updateExchangeStatus(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("exchangeStatus")int exchangeStatus);
	
	public int updateDeveloperBizId(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("bizId")String bizId);
	
	public int updateAddDeveloperBizId(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("bizId")String bizId);
	
	public int updateMainOrderNum(@Param("suffix")String suffix,
			@Param("orderNum")String orderNum, 
			@Param("mainOrderNum")String mainOrderNum);
	
	public int countConsumerJoinNum(@Param("suffix")String suffix,
			@Param("consumerId")long consumerId, 
			@Param("duibaActivityId")long duibaActivityId, 
			@Param("activityType")String activityType);
	
	public List<ActivityOrderEntity> findConsumerJoinList(@Param("suffix")String suffix,
			@Param("consumerId")long consumerId, 
			@Param("duibaActivityIds")List<Long> duibaActivityIds, 
			@Param("activityType")String activityType);
	
	ActivityOrderEntity findConsumerDuibaActivity4day(@Param("suffix")String suffix,
			@Param("consumerId")long consumerId, 
			@Param("duibaActivityId")Long duibaActivityId, 
			@Param("activityType")String activityType,
			@Param("start")String start, 
			@Param("end")String end);
	
	public List<ActivityOrderEntity> findByOrderNums(@Param("suffix")String suffix,
			@Param("orderNums") List<String> orderNums);
	
	public List<Long> findOptionIds(@Param("consumerId")Long consumerId, 
			@Param("appId")Long appId, 
			@Param("activityType")String activityType,
			@Param("suffix")String suffix);
	
	int updateAddCredits(
			@Param("suffix")String suffix,
			@Param("orderNum") String orderNum,
			@Param("addCredits") Long addCredits);
	
	
}
